#!/urs/bin/env python3

"""Module storing all `types`
Types stored in this module are simple classes with minimal logic

----------
Since:
  1.0
----------
------------
Version:
  1.0
------------
---------------
Author:
  Karafra
---------------
"""

# region Imports
from .Modes import Modes
from .ColorComponents import RGB
# endregion